==> parcel-bundler-vue-1.6.3.tgz: package/lib/WorkerFarm.js <==
'use strict';

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _get2 = require('babel-runtime/helpers/get');

var _get3 = _interopRequireDefault(_get2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _require = require('events'),
    EventEmitter = _require.EventEmitter;

var os = require('os');
var Farm = require('worker-farm/lib/farm');
var promisify = require('./utils/promisify');
var logger = require('./Logger');

var shared = null;

var WorkerFarm = function (_Farm) {
  (0, _inherits3.default)(WorkerFarm, _Farm);

  function WorkerFarm(options) {
    (0, _classCallCheck3.default)(this, WorkerFarm);

    var opts = {
      maxConcurrentWorkers: getNumWorkers()
    };

    var _this = (0, _possibleConstructorReturn3.default)(this, (WorkerFarm.__proto__ || (0, _getPrototypeOf2.default)(WorkerFarm)).call(this, opts, require.resolve('./worker')));

    _this.localWorker = _this.promisifyWorker(require('./worker'));
    _this.remoteWorker = _this.promisifyWorker(_this.setup(['init', 'run']));

    _this.started = false;
    _this.warmWorkers = 0;
    _this.init(options);
    return _this;
  }

  (0, _createClass3.default)(WorkerFarm, [{
    key: 'init',
    value: function init(options) {
      this.localWorker.init(options);
      this.initRemoteWorkers(options);
    }
  }, {
    key: 'promisifyWorker',
    value: function promisifyWorker(worker) {
      var res = {};

      for (var key in worker) {
        res[key] = promisify(worker[key].bind(worker));
      }

      return res;
    }
  }, {
    key: 'initRemoteWorkers',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(options) {
        var promises, i;
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                this.started = false;
                this.warmWorkers = 0;

                promises = [];

                for (i = 0; i < this.options.maxConcurrentWorkers; i++) {
                  promises.push(this.remoteWorker.init(options));
                }

                _context.next = 6;
                return _promise2.default.all(promises);

              case 6:
                if (this.options.maxConcurrentWorkers > 0) {
                  this.started = true;
                }

              case 7:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function initRemoteWorkers(_x) {
        return _ref.apply(this, arguments);
      }

      return initRemoteWorkers;
    }()
  }, {
    key: 'receive',
    value: function receive(data) {
      if (data.event) {
        this.emit.apply(this, [data.event].concat((0, _toConsumableArray3.default)(data.args)));
      } else if (data.type === 'logger') {
        if (this.shouldUseRemoteWorkers()) {
          logger.handleMessage(data);
        }
      } else if (this.children[data.child]) {
        (0, _get3.default)(WorkerFarm.prototype.__proto__ || (0, _getPrototypeOf2.default)(WorkerFarm.prototype), 'receive', this).call(this, data);
      }
    }
  }, {
    key: 'shouldUseRemoteWorkers',
    value: function shouldUseRemoteWorkers() {
      return this.started && this.warmWorkers >= this.activeChildren;
    }
  }, {
    key: 'run',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2() {
        var _this2 = this;

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        var _remoteWorker, _localWorker, _remoteWorker2;

        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                if (!this.shouldUseRemoteWorkers()) {
                  _context2.next = 4;
                  break;
                }

                return _context2.abrupt('return', (_remoteWorker = this.remoteWorker).run.apply(_remoteWorker, (0, _toConsumableArray3.default)(args).concat([false])));

              case 4:
                // Workers have started, but are not warmed up yet.
                // Send the job to a remote worker in the background,
                // but use the result from the local worker - it will be faster.
                if (this.started) {
                  (_remoteWorker2 = this.remoteWorker).run.apply(_remoteWorker2, (0, _toConsumableArray3.default)(args).concat([true])).then(function () {
                    _this2.warmWorkers++;
                  }, function () {
                    // ignore error
                  });
                }

                return _context2.abrupt('return', (_localWorker = this.localWorker).run.apply(_localWorker, (0, _toConsumableArray3.default)(args).concat([false])));

              case 6:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function run() {
        return _ref2.apply(this, arguments);
      }

      return run;
    }()
  }, {
    key: 'end',
    value: function end() {
      // Force kill all children
      this.ending = true;
      for (var child in this.children) {
        this.stopChild(child);
      }

      this.ending = false;
      shared = null;
    }
  }], [{
    key: 'getShared',
    value: function getShared(options) {
      if (!shared) {
        shared = new WorkerFarm(options);
      } else {
        shared.init(options);
      }

      return shared;
    }
  }]);
  return WorkerFarm;
}(Farm);

for (var key in EventEmitter.prototype) {
  WorkerFarm.prototype[key] = EventEmitter.prototype[key];
}

function getNumWorkers() {
  if (process.env.PARCEL_WORKERS) {
    return parseInt(process.env.PARCEL_WORKERS, 10);
  }

  var cores = void 0;
  try {
    cores = require('physical-cpu-count');
  } catch (err) {
    cores = os.cpus().length;
  }
  return cores || 1;
}

module.exports = WorkerFarm;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/WorkerFarm.js <==
'use strict';

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _get2 = require('babel-runtime/helpers/get');

var _get3 = _interopRequireDefault(_get2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _require = require('events'),
    EventEmitter = _require.EventEmitter;

var os = require('os');
var Farm = require('worker-farm/lib/farm');
var promisify = require('./utils/promisify');

var shared = null;

var WorkerFarm = function (_Farm) {
  (0, _inherits3.default)(WorkerFarm, _Farm);

  function WorkerFarm(options) {
    (0, _classCallCheck3.default)(this, WorkerFarm);

    var opts = {
      maxConcurrentWorkers: getNumWorkers()
    };

    var _this = (0, _possibleConstructorReturn3.default)(this, (WorkerFarm.__proto__ || (0, _getPrototypeOf2.default)(WorkerFarm)).call(this, opts, require.resolve('./worker')));

    _this.localWorker = _this.promisifyWorker(require('./worker'));
    _this.remoteWorker = _this.promisifyWorker(_this.setup(['init', 'run']));

    _this.started = false;
    _this.warmWorkers = 0;
    _this.init(options);
    return _this;
  }

  (0, _createClass3.default)(WorkerFarm, [{
    key: 'init',
    value: function init(options) {
      this.localWorker.init(options);
      this.initRemoteWorkers(options);
    }
  }, {
    key: 'promisifyWorker',
    value: function promisifyWorker(worker) {
      var res = {};

      for (var key in worker) {
        res[key] = promisify(worker[key].bind(worker));
      }

      return res;
    }
  }, {
    key: 'initRemoteWorkers',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee(options) {
        var promises, i;
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                this.started = false;

                promises = [];

                for (i = 0; i < this.options.maxConcurrentWorkers; i++) {
                  promises.push(this.remoteWorker.init(options));
                }

                _context.next = 5;
                return _promise2.default.all(promises);

              case 5:
                this.started = true;

              case 6:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function initRemoteWorkers(_x) {
        return _ref.apply(this, arguments);
      }

      return initRemoteWorkers;
    }()
  }, {
    key: 'receive',
    value: function receive(data) {
      if (data.event) {
        this.emit.apply(this, [data.event].concat((0, _toConsumableArray3.default)(data.args)));
      } else {
        (0, _get3.default)(WorkerFarm.prototype.__proto__ || (0, _getPrototypeOf2.default)(WorkerFarm.prototype), 'receive', this).call(this, data);
      }
    }
  }, {
    key: 'run',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2() {
        var _this2 = this;

        var _remoteWorker,
            _localWorker,
            _remoteWorker2,
            _args2 = arguments;

        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                if (!(this.started && this.warmWorkers >= this.activeChildren)) {
                  _context2.next = 4;
                  break;
                }

                return _context2.abrupt('return', (_remoteWorker = this.remoteWorker).run.apply(_remoteWorker, _args2));

              case 4:
                // Workers have started, but are not warmed up yet.
                // Send the job to a remote worker in the background,
                // but use the result from the local worker - it will be faster.
                if (this.started) {
                  (_remoteWorker2 = this.remoteWorker).run.apply(_remoteWorker2, _args2).then(function () {
                    _this2.warmWorkers++;
                  });
                }

                return _context2.abrupt('return', (_localWorker = this.localWorker).run.apply(_localWorker, _args2));

              case 6:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function run() {
        return _ref2.apply(this, arguments);
      }

      return run;
    }()
  }, {
    key: 'end',
    value: function end() {
      (0, _get3.default)(WorkerFarm.prototype.__proto__ || (0, _getPrototypeOf2.default)(WorkerFarm.prototype), 'end', this).call(this);
      shared = null;
    }
  }], [{
    key: 'getShared',
    value: function getShared(options) {
      if (!shared) {
        shared = new WorkerFarm(options);
      } else {
        shared.init(options);
      }

      return shared;
    }
  }]);
  return WorkerFarm;
}(Farm);

for (var key in EventEmitter.prototype) {
  WorkerFarm.prototype[key] = EventEmitter.prototype[key];
}

function getNumWorkers() {
  var cores = void 0;
  try {
    cores = require('physical-cpu-count');
  } catch (err) {
    cores = os.cpus().length;
  }
  return cores || 1;
}

module.exports = WorkerFarm;
